@@ -19,6 +19,7 @@ from gooddata_metadata_client.model.declarative_attribute import DeclarativeAttr
 from gooddata_metadata_client.model.declarative_column import DeclarativeColumn
 from gooddata_metadata_client.model.declarative_dashboard_plugin import DeclarativeDashboardPlugin
 from gooddata_metadata_client.model.declarative_data_source import DeclarativeDataSource
+from gooddata_metadata_client.model.declarative_data_source_permission import DeclarativeDataSourcePermission
 from gooddata_metadata_client.model.declarative_data_sources import DeclarativeDataSources
 from gooddata_metadata_client.model.declarative_dataset import DeclarativeDataset
 from gooddata_metadata_client.model.declarative_date_dataset import DeclarativeDateDataset
@@ -33,6 +34,7 @@ from gooddata_metadata_client.model.declarative_organization_info import Declara
 from gooddata_metadata_client.model.declarative_organization_permission import DeclarativeOrganizationPermission
 from gooddata_metadata_client.model.declarative_pdm import DeclarativePdm
 from gooddata_metadata_client.model.declarative_reference import DeclarativeReference
+from gooddata_metadata_client.model.declarative_single_workspace_permission import DeclarativeSingleWorkspacePermission
 from gooddata_metadata_client.model.declarative_table import DeclarativeTable
 from gooddata_metadata_client.model.declarative_tables import DeclarativeTables
 from gooddata_metadata_client.model.declarative_user import DeclarativeUser
@@ -45,7 +47,9 @@ from gooddata_metadata_client.model.declarative_workspace import DeclarativeWork
 from gooddata_metadata_client.model.declarative_workspace_data_filter import DeclarativeWorkspaceDataFilter
 from gooddata_metadata_client.model.declarative_workspace_data_filter_setting import DeclarativeWorkspaceDataFilterSetting
 from gooddata_metadata_client.model.declarative_workspace_data_filters import DeclarativeWorkspaceDataFilters
+from gooddata_metadata_client.model.declarative_workspace_hierarchy_permission import DeclarativeWorkspaceHierarchyPermission
 from gooddata_metadata_client.model.declarative_workspace_model import DeclarativeWorkspaceModel
+from gooddata_metadata_client.model.declarative_workspace_permissions import DeclarativeWorkspacePermissions
 from gooddata_metadata_client.model.declarative_workspaces import DeclarativeWorkspaces
 from gooddata_metadata_client.model.generate_ldm_request import GenerateLdmRequest
 from gooddata_metadata_client.model.grain_identifier import GrainIdentifier
@@ -107,6 +111,11 @@ from gooddata_metadata_client.model.json_api_dashboard_plugin_out_with_links imp
 from gooddata_metadata_client.model.json_api_dashboard_plugin_patch import JsonApiDashboardPluginPatch
 from gooddata_metadata_client.model.json_api_dashboard_plugin_patch_document import JsonApiDashboardPluginPatchDocument
 from gooddata_metadata_client.model.json_api_dashboard_plugin_to_many_linkage import JsonApiDashboardPluginToManyLinkage
+from gooddata_metadata_client.model.json_api_data_source_identifier_out import JsonApiDataSourceIdentifierOut
+from gooddata_metadata_client.model.json_api_data_source_identifier_out_attributes import JsonApiDataSourceIdentifierOutAttributes
+from gooddata_metadata_client.model.json_api_data_source_identifier_out_document import JsonApiDataSourceIdentifierOutDocument
+from gooddata_metadata_client.model.json_api_data_source_identifier_out_list import JsonApiDataSourceIdentifierOutList
+from gooddata_metadata_client.model.json_api_data_source_identifier_out_with_links import JsonApiDataSourceIdentifierOutWithLinks
 from gooddata_metadata_client.model.json_api_data_source_in import JsonApiDataSourceIn
 from gooddata_metadata_client.model.json_api_data_source_in_attributes import JsonApiDataSourceInAttributes
 from gooddata_metadata_client.model.json_api_data_source_in_document import JsonApiDataSourceInDocument
@@ -114,6 +123,7 @@ from gooddata_metadata_client.model.json_api_data_source_out import JsonApiDataS
 from gooddata_metadata_client.model.json_api_data_source_out_attributes import JsonApiDataSourceOutAttributes
 from gooddata_metadata_client.model.json_api_data_source_out_document import JsonApiDataSourceOutDocument
 from gooddata_metadata_client.model.json_api_data_source_out_list import JsonApiDataSourceOutList
+from gooddata_metadata_client.model.json_api_data_source_out_meta import JsonApiDataSourceOutMeta
 from gooddata_metadata_client.model.json_api_data_source_out_with_links import JsonApiDataSourceOutWithLinks
 from gooddata_metadata_client.model.json_api_data_source_patch import JsonApiDataSourcePatch
 from gooddata_metadata_client.model.json_api_data_source_patch_attributes import JsonApiDataSourcePatchAttributes
